# 费用试算

#### 接口方法

- getShippingRate


#### 请求方式：

- POST


#### 请求示例:

```xml
<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" xmlns:ns1="http://www.example.org/">
	<SOAP-ENV:Body>
		<ns1:callService>
			<paramsJson>
				{
					"warehouse_code":"WEST",
					"sm_code":"US_FEDEX_GROUND",
					"country_code":"US",
					"post_code":"",
					"zone":"4",
					"is_residential":"0",
					"product_list":
					[
						{
							"product_sku":"trialsku001",
							"length":"42.28",
							"width":"23.64",
							"height":"23.64",
							"weight":"25.21"
						}
					]
				}
			</paramsJson>
			<appToken>appToken</appToken>
			<appKey>appKey</appKey>
			<service>getShippingRate</service>
		</ns1:callService>
	</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
```


#### 请求参数:

|参数   |类型   |是否必填   |说明   |长度限制
| :------------ | :------------ | :------------ | :------------ | :------------ |
|warehouse_code |String |是 |仓库 |20
|sm_code |String |否 |派送方式，填写则试算单个渠道，不填写试算系统配置的多个渠道 |20
|country_code |String |是 |国际简称 |20
|post_code |String |否 |邮编(邮编和分区至少填写一个) |20
|zone |String |否 |分区(邮编和分区至少填写一个,欧洲地址请勿填写分区) |20
|is_residential |int |否 |是否住宅 1.是 0.否（默认0） |
|product_list |Object |是 |试算SKU尺寸重量（最多五个） |

#### product_list参数:

|参数   |类型   |是否必填   |说明   |长度限制
| :------------ | :------------ | :------------ | :------------ | :------------ |
|product_sku |String |是 |试算sku |20
|length |String |是 |长（cm） |20
|width |String |是 |宽（cm） |20
|height |String |是 |高（cm） |20
|weight |String |是 |重量（kg） |20


#### 返回结果示例：

```xml
<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<SOAP-ENV:Envelope xmlns:ns1="http://www.example.org/" xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/">
	<SOAP-ENV:Body>
		<callServiceResponse>
			<response>
				{
					"ask":"Success",
					"data":[
							{
								"additional_handling_fee": 10.0,
								"basic_fee": 56.40,
								"currency": "USD",
								"delivery_area_surcharge_extended_fee": 0,
								"delivery_area_surcharge_fee": 0,
								"fuel_fee": 12.31,
								"fuel_fee_rate": 0.1700000,
								"over_maximum_limits_fee": 0,
								"oversize_surcharge": 0,
								"peak_surcharge_fee": 6.0,
								"picking_charge": 2550.60,
								"product_sku": "trialsku001",
								"rent_charge": 708.84,
								"residential_delivery_fee": 0,
								"sm_code": "US_FEDEX_GROUND",
								"total_fee": 3344.15,
								"traffic_congestion_fee": 0,
								"unloading_fee": 0.00,
								"peak_surcharge_fee": 0.00,
								"zone": 4,
								"product_fee_weight_lb": 56.00,
								"product_girth_in": 57.00,
								"product_height": 23.64,
								"product_height_in": 9.31,
								"product_length": 42.28,
								"product_length_in": 16.65,
								"product_sku": "trialsku001",
								"product_volume_weight_lb": 6.80,
								"product_weight": 25.21,
								"product_weight_lb": 55.58,
								"product_width": 23.64,
								"product_width_in": 9.31
							}
						],
					"nextPage":false
				}
			</response>
		</callServiceResponse>
	</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
```


#### 返回参数：

|参数   |类型   |说明   |
| :------------ | :------------ | :------------ |
|ask   |String   |返回结果，Success表示请求成功，Failure表示请求失败   |
|message   |String   |返回信息   |
|nextPage  |boolean   |true 有下一页，false 没有下一页   |
|product_sku   |String   |试算sku  |
|product_length   |BigDecimal   |长（cm）  |
|product_length_in   |BigDecimal   |长（inch）  |
|product_width   |BigDecimal   |宽（cm）  |
|product_width_in   |BigDecimal   |宽（inch）  |
|product_height   |BigDecimal   |高（cm）  |
|product_height_in   |BigDecimal   |高（inch）  |
|product_weight   |BigDecimal   |重量（kg）  |
|product_weight_lb   |BigDecimal   |重量（lb）  |
|product_girth_in   |BigDecimal   |围长（inch）  |
|product_volume_weight_lb   |BigDecimal   |体积重（lb）  |
|product_fee_weight_lb   |BigDecimal   |计费重（lb）  |
|product_fee_weight   |BigDecimal   |计费重（kg）  |
|zone   |String   |分区  |
|fee_detail_list |list |费用明细

#### fee_detail_list返回参数：

|参数   |类型   |说明   |
| :------------ | :------------ | :------------ |
|product_sku   |String   |试算sku  |
|unloading_fee |BigDecimal |入库费-卸货费
|rent_charge |BigDecimal |仓租-30天仓租
|picking_charge |BigDecimal |出库费-拣货费
|basic_fee |BigDecimal |物流费-基础费
|fuel_fee |BigDecimal |物流费-燃油费
|fuel_fee_rate |BigDecimal |物流费-燃油费率
|residential_delivery_fee |BigDecimal |物流费-住宅附加费
|sm_code   |String   |派送方式  |
|additional_handling_fee |BigDecimal |物流费-额外处理费
|oversize_surcharge |BigDecimal |超尺寸附加费(大包裹费)
|over_maximum_limits_fee |BigDecimal |超最大尺寸限制收费
|delivery_area_surcharge_fee |BigDecimal |偏远地址费用
|delivery_area_surcharge_extended_fee |BigDecimal |超偏远地址费用
|traffic_congestion_fee |BigDecimal |DHL通行费
|peak_surcharge_fee |BigDecimal |旺季附加费
|total_fee |BigDecimal |全流程汇总
|currency   |String   |币种  |